@@ -276,7 +276,7 @@ class BigQueryClient(object):
             body=body_object
         ).execute()
 
-    def query(self, query, max_results=None, timeout=0, dry_run=False, use_legacy_sql=None):
+    def query(self, query, max_results=None, timeout=0, dry_run=False, use_legacy_sql=None, external_udf_uris=None):
         """Submit a query to BigQuery.
 
         Parameters
@@ -294,6 +294,9 @@ class BigQueryClient(object):
             message it would if it wasn't a dry run.
         use_legacy_sql : bool, optional. Default True.
             If False, the query will use BigQuery's standard SQL (https://cloud.google.com/bigquery/sql-reference/)
+        external_udf_uris : list, optional
+            Contains external UDF URIs. If given, URIs must be Google Cloud
+            Storage and have .js extensions.
 
 
         Returns
@@ -321,6 +324,10 @@ class BigQueryClient(object):
         if use_legacy_sql is not None:
             query_data['useLegacySql'] = use_legacy_sql
 
+        if external_udf_uris:
+            query_data['userDefinedFunctionResources'] = \
+                [ {'resourceUri': u} for u in external_udf_uris ]
+
         return self._submit_query_job(query_data)
 
     def get_query_schema(self, job_id):
@@ -520,7 +527,8 @@ class BigQueryClient(object):
 
         return table
 
-    def create_table(self, dataset, table, schema, expiration_time=None):
+    def create_table(self, dataset, table, schema,
+                     expiration_time=None, time_partitioning=False):
         """Create a new table in the dataset.
 
         Parameters
@@ -533,6 +541,8 @@ class BigQueryClient(object):
             The table schema
         expiration_time : float, optional
             The expiry time in milliseconds since the epoch.
+        time_partitioning : bool, optional
+            Create a time partitioning.
 
         Returns
         -------
@@ -553,6 +563,9 @@ class BigQueryClient(object):
         if expiration_time is not None:
             body['expirationTime'] = expiration_time
 
+        if time_partitioning:
+            body['timePartitioning'] = {'type': 'DAY'}
+
         try:
             table = self.bigquery.tables().insert(
                 projectId=self.project_id,
@@ -1042,7 +1055,7 @@ class BigQueryClient(object):
             query,
             dataset=None,
             table=None,
-            external_udf_uris=[],
+            external_udf_uris=None,
             allow_large_results=None,
             use_query_cache=None,
             priority=None,
@@ -1067,7 +1080,7 @@ class BigQueryClient(object):
         table : str, optional
             String id of the table
         external_udf_uris : list, optional
-            Contains extternal UDF URIs. If given, URIs must be Google Cloud
+            Contains external UDF URIs. If given, URIs must be Google Cloud
             Storage and have .js extensions.
         allow_large_results : bool, optional
             Whether or not to allow large results
@@ -1138,13 +1151,9 @@ class BigQueryClient(object):
         if write_disposition:
             configuration['writeDisposition'] = write_disposition
 
-        configuration['userDefinedFunctionResources'] = []
-        for external_udf_uri in external_udf_uris:
-            configuration['userDefinedFunctionResources'].append(
-                {
-                    "resourceUri": external_udf_uri
-                }
-            )
+        if external_udf_uris:
+            configuration['userDefinedFunctionResources'] = \
+                [ {'resourceUri': u} for u in external_udf_uris ]
 
         body = {
             "configuration": {
@@ -1649,7 +1658,7 @@ class BigQueryClient(object):
     # DataSet manipulation methods
     #
     def create_dataset(self, dataset_id, friendly_name=None, description=None,
-                       access=None):
+                       access=None, location=None):
         """Create a new BigQuery dataset.
 
         Parameters
@@ -1664,6 +1673,9 @@ class BigQueryClient(object):
         access : list, optional
             Indicating access permissions (see
             https://developers.google.com/bigquery/docs/reference/v2/datasets#resource)
+        location : str, optional
+            Indicating where dataset should be stored: EU or US (see
+            https://developers.google.com/bigquery/docs/reference/v2/datasets#resource)
 
         Returns
         -------
@@ -1676,7 +1688,8 @@ class BigQueryClient(object):
             dataset_data = self.dataset_resource(dataset_id,
                                                  friendly_name=friendly_name,
                                                  description=description,
-                                                 access=access)
+                                                 access=access,
+                                                 location=location)
 
             response = datasets.insert(projectId=self.project_id,
                                        body=dataset_data).execute()
@@ -1837,7 +1850,7 @@ class BigQueryClient(object):
                 return {}
 
     def dataset_resource(self, ref_id, friendly_name=None, description=None,
-                         access=None):
+                         access=None, location=None):
         """See
         https://developers.google.com/bigquery/docs/reference/v2/datasets#resource
 
@@ -1851,6 +1864,8 @@ class BigQueryClient(object):
             An optional description for the dataset
         access : list, optional
             Indicating access permissions
+        location: str, optional, 'EU' or 'US'
+            An optional geographical location for the dataset(EU or US)
 
         Returns
         -------
@@ -1869,6 +1884,8 @@ class BigQueryClient(object):
             data["description"] = description
         if access:
             data["access"] = access
+        if location:
+            data["location"] = location
 
         return data
 
